@@ -38,10 +38,8 @@ long pth_version(void)
 intern int pth_initialized = FALSE;
 #if cpp
 #define pth_implicit_init() \
-    if (!pth_initialized) { \
-        pth_initialized = TRUE; \
-        pth_init(); \
-    }
+    if (!pth_initialized) \
+        pth_init();
 #endif
 
 /* initialize the package */
@@ -49,10 +47,14 @@ int pth_init(void)
 {
     pth_attr_t t_attr;
 
-    pth_debug1("pth_init: enter");
-
+    /* support for implicit initialization calls
+       and to prevent multiple explict initialization, too */
     if (pth_initialized)
         return FALSE;
+    else
+        pth_initialized = TRUE;
+
+    pth_debug1("pth_init: enter");
 
     /* initialize the scheduler */
     pth_scheduler_init();
