@@ -21,7 +21,9 @@
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
 */
-
+                             /* ``Those who do not understand Unix 
+                                  are condemned to reinvent it, poorly.''
+                                                   -- Henry Spencer      */
 #include "pth_p.h"
 
 #if cpp
@@ -48,7 +50,7 @@ pth_msgport_t pth_msgport_create(const char *name)
         return_errno(NULL, EINVAL);
 
     /* allocate message port structure */
-    if ((mp = malloc(sizeof(struct pth_msgport_st))) == NULL)
+    if ((mp = (pth_msgport_t)malloc(sizeof(struct pth_msgport_st))) == NULL)
         return_errno(NULL, ENOMEM);
 
     /* initialize structure */
