@@ -313,20 +313,23 @@ int pthread_equal(pthread_t t1, pthread_t t2)
     return (t1 == t2);
 }
 
-void pthread_yield_np(void)
+int pthread_yield_np(void)
 {
+    pthread_initialize();
     pth_yield(NULL);
-    return;
+    return OK;
 }
 
 void pthread_exit(void *value_ptr)
 {
+    pthread_initialize();
     pth_exit(value_ptr);
     return;
 }
 
 int pthread_join(pthread_t thread, void **value_ptr)
 {
+    pthread_initialize();
     if (!pth_join((pth_t)thread, value_ptr))
         return errno;
     if (value_ptr != NULL)
@@ -947,7 +950,13 @@ int pthread_cond_timedwait(pthread_cond_t *cond, pthread_mutex_t *mutex,
     pth_event_t ev;
     static pth_key_t ev_key = PTH_KEY_INIT;
 
-    if (cond == NULL || mutex == NULL)
+    if (cond == NULL || mutex == NULL || abstime == NULL)
+        return_errno(EINVAL, EINVAL);
+#ifdef __amigaos__
+    if (abstime->ts_sec < 0 || abstime->ts_nsec < 0 || abstime->ts_nsec >= 1000000000)
+#else
+    if (abstime->tv_sec < 0 || abstime->tv_nsec < 0 || abstime->tv_nsec >= 1000000000)
+#endif
         return_errno(EINVAL, EINVAL);
     if (*cond == PTHREAD_COND_INITIALIZER)
         if (pthread_cond_init(cond, NULL) != OK)
